SimpleSelfRebuff:_rev("$Revision: 43112 $")

-------------------------------------------------------------------------------
-- Externals
-------------------------------------------------------------------------------

local SimpleSelfRebuff = SimpleSelfRebuff

local L = AceLibrary("AceLocale-2.2"):new("SimpleSelfRebuff")
local Tablet = AceLibrary('Tablet-2.0')

local colorize = SimpleSelfRebuff.colorize
local formatDuration = SimpleSelfRebuff.formatDuration

-------------------------------------------------------------------------------
-- Helpers
-------------------------------------------------------------------------------

local function GetBuffInfo(category)

	local expectedBuff = category:GetExpectedBuff()
	if not expectedBuff then
		return
	end
	
	local actualBuff, timeLeft = category:GetActualBuff()
	if not actualBuff then
		return expectedBuff.name, L["Missing"], 1, 0, 0
	end
	
	timeLeft = formatDuration(timeLeft, "-")
	if actualBuff == expectedBuff then
		return actualBuff.name, timeLeft, 0, 1, 0
	else
		return actualBuff.name, timeLeft, 1, 1, 0
	end
	
end

-------------------------------------------------------------------------------
-- Module declaration
-------------------------------------------------------------------------------

local FuBarPlugin = SimpleSelfRebuff:NewModule("FuBarPlugin", "FuBarPlugin-2.0")

FuBarPlugin.OnMenuRequest = SimpleSelfRebuff.options
FuBarPlugin.options = AceLibrary("FuBarPlugin-2.0"):GetAceOptionsDataTable(FuBarPlugin)
FuBarPlugin.optionName = L["FuBar settings"]
FuBarPlugin.optionOrder = -4
 
function FuBarPlugin:OnModuleInitialize()
	self.name = SimpleSelfRebuff.name
	self.version = SimpleSelfRebuff.version
	self.revision = SimpleSelfRebuff.revision		
end

function FuBarPlugin:OnModuleEnable()
	self:RegisterBucketEvent('SimpleSelfRebuff_UpdateDisplay', 0.1, 'UpdateDisplay')
end

function FuBarPlugin:OnTextUpdate()
	local active = self.core:IsMonitoringActive()
	if active then
		local buffToCast = self.core:GetPendingCast()
		if buffToCast then
			local name, timeLeft, r, g, b = GetBuffInfo(buffToCast.category)
			self:SetText(colorize(timeLeft, r, g, b))
			self:ScheduleEvent('SimpleSelfRebuff_UpdateDisplay', 1)
			--self:SetIcon(BS:GetSpellIcon(buffToCast))
		else
			self:SetText('SSR')
			--self:SetIcon(false)
		end
	else
		self:SetText('|cff777777SSR|r')
		--self:SetIcon(false)
	end
end

function FuBarPlugin:OnTooltipUpdate()
	local active = self.core:IsMonitoringActive()
	local cat
	Tablet:SetTitle(self.core.name)
	if not active then
		cat = Tablet:AddCategory()
		cat:AddLine('text', L["Currently inactive (resting/dead)."])
	else
		cat = Tablet:AddCategory("columns", 3)
		for categoryName, category in pairs(self.core.categories) do
			if category.count > 0 then
				local name, timeLeft, r, g, b = GetBuffInfo(category)
				if name then
					cat:AddLine(
						'text',  categoryName,
						'text2', name,     'text2R', r, 'text2G', g, 'text2B', b,
						'text3', timeLeft, 'text3R', r, 'text3G', g, 'text3B', b
					)
				end
			end
		end
		self:ScheduleEvent('SimpleSelfRebuff_UpdateDisplay', 1)		
		Tablet:SetHint(L["Green means \"ok\", yellow means \"override wanted buff\", red means \"missing\"."])
	end
end
