SimpleSelfRebuff:_rev("$Revision: 43077 $")

-------------------------------------------------------------------------------
-- Externals
-------------------------------------------------------------------------------

local SimpleSelfRebuff = SimpleSelfRebuff
local L = AceLibrary("AceLocale-2.2"):new("SimpleSelfRebuff")

local formatDuration = SimpleSelfRebuff.formatDuration
local colorize = SimpleSelfRebuff.colorize

-------------------------------------------------------------------------------
-- Locals
-------------------------------------------------------------------------------

local reminderDests = {}
local db

-------------------------------------------------------------------------------
-- Module declaration
-------------------------------------------------------------------------------
	
local Reminder = SimpleSelfRebuff:NewModule('Reminder')

-------------------------------------------------------------------------------
-- Option declaration
-------------------------------------------------------------------------------
	
Reminder.optionName = L["Reminder"]
Reminder.optionDesc = L["Configure the reminder."]

local function IsReminderDisabled()
	return not SimpleSelfRebuff:IsModuleActive(Reminder)
end

local function SCTDisabled()
	return IsReminderDisabled() or not SCT
end

local function MSBTDisabled()
	return IsReminderDisabled() or not MikSBT
end

local function getReminderColor(key)
	local c = db.colors[key]
	return c.r, c.g, c.b
end

local function setReminderColor(key, r, g, b)
	local c = db.colors[key]
	c.r, c.g, c.b = r, g, b
end
	
Reminder.options = {
	colorHeader = {
		type = 'header',
		name = L["Colors"],
		order = 79,
	},
	missingColor = {
		type = 'color',
		name = L["Missing message"],
		desc = L["Set the color of the missing message."],
		get = getReminderColor,
		set = setReminderColor,
		passValue = 'missing',
		disabled = IsReminderDisabled,
		order = 80,
	},
	refreshingColor = {
		type = 'color',
		name = L["Refreshing message"],
		desc = L["Set the color of the refreshing message."],
		get = getReminderColor,
		set = setReminderColor,
		passValue = 'refreshing',
		disabled = function() return IsReminderDisabled() or SimpleSelfRebuff.db.profile.rebuffThreshold == 0 end,
		order = 80,
	},
	--
	destHeader = {
		type = 'header',
		name = L["Displays"],
		order = 99,
	},
	chat = {
		type = 'toggle',
		name = L["Chat Frame"],
		desc = L["Print reminder into chat frame."],
		passValue = "chat",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination", 
		disabled = IsReminderDisabled,
	},
	uierror = {
		type = 'toggle',
		name = L["Blizzard error frame"],
		desc = L["Print reminder into Blizzard error frame."],
		passValue = "uierror",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination", 
		disabled = IsReminderDisabled,
	},
	sctText1 = {
		type = 'toggle',
		name = L["SCT Text #1"],
		desc = L["Show reminder with SCT text #1."],
		passValue = "sctText1",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination", 				
		disabled = SCTDisabled,
	},
	sctText2 = {
		type = 'toggle',
		name = L["SCT Text #2"],
		desc = L["Show reminder with SCT text #2."],
		passValue = "sctText2",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination",				
		disabled = SCTDisabled,
	},
	sctMessage = {
		type = 'toggle',
		name = L["SCT Message"],
		desc = L["Show reminder as SCT message."],
		passValue = "sctMessage",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination",				
		disabled = SCTDisabled,
	},
	mikSBT = {
		type = 'toggle',
		name = L["MikSBT Message"],
		desc = L["Show reminder as MikSBT message."],
		passValue = "MikSBT",
		get = "IsReminderDestinationEnabled",
		set = "ToggleReminderDestination",				
		disabled = MSBTDisabled,
	},
}

-------------------------------------------------------------------------------
-- Module core
-------------------------------------------------------------------------------

function Reminder:OnModuleInitialize()
	self:RegisterDefaults('profile', {
		destinations = {
			chat = true,
			sctMessage = true,
		},
		colors = {
			missing    = { r=0.9, g=0.2, b=0.2 },
			refreshing = { r=0.9, g=0.6, b=0.2 },
		},
	})
	db = self.db.profile
end

function Reminder:OnModuleEnable()
	self:RegisterEvent('SimpleSelfRebuff_PendingCastChanged', 'PrintMessage')
end

function Reminder:IsReminderDestinationEnabled(dest)
	return db.destinations[dest]
end

function Reminder:ToggleReminderDestination(dest, value)
	db.destinations[dest] = value and true or nil
end

function Reminder:PrintMessage(buff, timeLeft)
	if not buff or not next(db.destinations) then
		return
	end
	local text, color
	if (timeLeft or 0) > 0 then
		text = L["%s expires in %s."]:format(buff.name, formatDuration(timeLeft))
		color = db.colors.refreshing
	else
		text = L["%s is missing."]:format(buff.name)
		color = db.colors.missing
	end 
	for dest,value in pairs(db.destinations) do
		if value and reminderDests[dest] then
			reminderDests[dest](self, text, color)
		end
	end
end

-------------------------------------------------------------------------------
-- Destinations
-------------------------------------------------------------------------------

function reminderDests:chat(text, color)
	self.core:Print(colorize(text, color.r, color.g, color.b))
end

function reminderDests:uierror(text, color)
	UIErrorsFrame:AddMessage(text, color.r, color.g, color.b)
end

function reminderDests:sctText1(text, color)
	if SCT then
		SCT:DisplayText(text, color, false, "event", 1)
	end
end

function reminderDests:sctText2(text, color)
	if SCT then
		SCT:DisplayText(text, color, false, "event", 2)
	end
end

function reminderDests:sctMessage(text, color)
	if SCT then
		SCT:DisplayMessage(text, color)
	end
end

function reminderDests:MikSBT(text, color)
	MikSBT.DisplayMessage(text, MikSBT.DISPLAYTYPE_NOTIFICATION, false, color.r * 255, color.g * 255, color.b * 255)
end